<!--
&lt;--- Readme.md Snippet without images Start ---&gt;
## Tech Stack
erling6232/imagedata is built on the following main stack:

- [Python](https://www.python.org) – Languages
- [NumPy](http://www.numpy.org/) – Data Science Tools
- [Matplotlib](http://matplotlib.org) – Charting Libraries
- [SciPy](http://www.scipy.org) – Data Science Tools
- [dicom](https://github.com/suyashkumar/dicom) – Image Processing and Management
- [GitHub Actions](https://github.com/features/actions) – Continuous Integration
- [LangChain](https://github.com/hwchase17/langchain) – Large Language Model Tools
- [pgvector](https://github.com/pgvector/pgvector/) – Database Tools
- [Travis CI](http://travis-ci.com/) – Continuous Integration

Full tech stack [here](/techstack.md)

&lt;--- Readme.md Snippet without images End ---&gt;

&lt;--- Readme.md Snippet with images Start ---&gt;
## Tech Stack
erling6232/imagedata is built on the following main stack:

- <img width='25' height='25' src='https://img.stackshare.io/service/993/pUBY5pVj.png' alt='Python'/> [Python](https://www.python.org) – Languages
- <img width='25' height='25' src='https://img.stackshare.io/service/2179/default_332f874a2edb2686f578aa6389313efcea1eec41.png' alt='NumPy'/> [NumPy](http://www.numpy.org/) – Data Science Tools
- <img width='25' height='25' src='https://img.stackshare.io/service/2993/2DZC4KaA_400x400.jpg' alt='Matplotlib'/> [Matplotlib](http://matplotlib.org) – Charting Libraries
- <img width='25' height='25' src='https://img.stackshare.io/service/3303/scipyshiny_small.png' alt='SciPy'/> [SciPy](http://www.scipy.org) – Data Science Tools
- <img width='25' height='25' src='https://img.stackshare.io/service/11171/dicom.png' alt='dicom'/> [dicom](https://github.com/suyashkumar/dicom) – Image Processing and Management
- <img width='25' height='25' src='https://img.stackshare.io/service/11563/actions.png' alt='GitHub Actions'/> [GitHub Actions](https://github.com/features/actions) – Continuous Integration
- <img width='25' height='25' src='https://img.stackshare.io/service/48790/default_5b6c6b73f1ff3775c85d2a1ba954cb87e30cbf13.jpg' alt='LangChain'/> [LangChain](https://github.com/hwchase17/langchain) – Large Language Model Tools
- <img width='25' height='25' src='https://img.stackshare.io/service/109221/default_b888cdf5617d936aa6aacf130911906955508639.png' alt='pgvector'/> [pgvector](https://github.com/pgvector/pgvector/) – Database Tools
- <img width='25' height='25' src='https://img.stackshare.io/service/460/Lu6cGu0z_400x400.png' alt='Travis CI'/> [Travis CI](http://travis-ci.com/) – Continuous Integration

Full tech stack [here](/techstack.md)

&lt;--- Readme.md Snippet with images End ---&gt;
-->
<div align="center">

# Tech Stack File
![](https://img.stackshare.io/repo.svg "repo") [erling6232/imagedata](https://github.com/erling6232/imagedata)![](https://img.stackshare.io/public_badge.svg "public")
<br/><br/>
|22<br/>Tools used|12/14/23 <br/>Report generated|
|------|------|
</div>

## <img src='https://img.stackshare.io/languages.svg'/> Languages (1)
<table><tr>
  <td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/993/pUBY5pVj.png' alt='Python'>
  <br>
  <sub><a href="https://www.python.org">Python</a></sub>
  <br>
  <sub></sub>
</td>

</tr>
</table>

## <img src='https://img.stackshare.io/frameworks.svg'/> Frameworks (1)
<table><tr>
  <td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/2993/2DZC4KaA_400x400.jpg' alt='Matplotlib'>
  <br>
  <sub><a href="http://matplotlib.org">Matplotlib</a></sub>
  <br>
  <sub></sub>
</td>

</tr>
</table>

## <img src='https://img.stackshare.io/databases.svg'/> Data (1)
<table><tr>
  <td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/109221/default_b888cdf5617d936aa6aacf130911906955508639.png' alt='pgvector'>
  <br>
  <sub><a href="https://github.com/pgvector/pgvector/">pgvector</a></sub>
  <br>
  <sub></sub>
</td>

</tr>
</table>

## <img src='https://img.stackshare.io/devops.svg'/> DevOps (4)
<table><tr>
  <td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/1046/git.png' alt='Git'>
  <br>
  <sub><a href="http://git-scm.com/">Git</a></sub>
  <br>
  <sub></sub>
</td>

<td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/11563/actions.png' alt='GitHub Actions'>
  <br>
  <sub><a href="https://github.com/features/actions">GitHub Actions</a></sub>
  <br>
  <sub></sub>
</td>

<td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/12572/-RIWgodF_400x400.jpg' alt='PyPI'>
  <br>
  <sub><a href="https://pypi.org/">PyPI</a></sub>
  <br>
  <sub></sub>
</td>

<td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/460/Lu6cGu0z_400x400.png' alt='Travis CI'>
  <br>
  <sub><a href="http://travis-ci.com/">Travis CI</a></sub>
  <br>
  <sub></sub>
</td>

</tr>
</table>

## <img src='https://img.stackshare.io/saas.svg'/> Software as a Service (SaaS) (1)
<table><tr>
  <td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/11171/dicom.png' alt='dicom'>
  <br>
  <sub><a href="https://github.com/suyashkumar/dicom">dicom</a></sub>
  <br>
  <sub></sub>
</td>

</tr>
</table>

## Other (3)
<table><tr>
  <td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/48790/default_5b6c6b73f1ff3775c85d2a1ba954cb87e30cbf13.jpg' alt='LangChain'>
  <br>
  <sub><a href="https://github.com/hwchase17/langchain">LangChain</a></sub>
  <br>
  <sub></sub>
</td>

<td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/2179/default_332f874a2edb2686f578aa6389313efcea1eec41.png' alt='NumPy'>
  <br>
  <sub><a href="http://www.numpy.org/">NumPy</a></sub>
  <br>
  <sub></sub>
</td>

<td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/3303/scipyshiny_small.png' alt='SciPy'>
  <br>
  <sub><a href="http://www.scipy.org">SciPy</a></sub>
  <br>
  <sub></sub>
</td>

</tr>
</table>


## <img src='https://img.stackshare.io/group.svg' /> Open source packages (11)</h2>

## <img width='24' height='24' src='https://img.stackshare.io/service/12572/-RIWgodF_400x400.jpg'/> PyPI (11)

|NAME|VERSION|LAST UPDATED|LAST UPDATED BY|LICENSE|VULNERABILITIES|
|:------|:------|:------|:------|:------|:------|
|[Sphinx](https://pypi.org/project/Sphinx)|N/A|10/11/23|Erling Andersen |BSD-3-Clause|N/A|
|[flake8](https://pypi.org/project/flake8)|N/A|09/06/21|Erling Andersen |MIT|N/A|
|[imageio](https://pypi.org/project/imageio)|N/A|03/03/21|Erling Andersen |BSD-3-Clause|N/A|
|[nibabel](https://pypi.org/project/nibabel)|N/A|03/03/21|Erling Andersen |MIT|N/A|
|[pandas](https://pypi.org/project/pandas)|N/A|05/15/23|Erling Andersen |BSD-3-Clause|N/A|
|[pydicom](https://pypi.org/project/pydicom)|N/A|03/03/21|Erling Andersen |MIT|N/A|
|[python-magic](https://pypi.org/project/python-magic)|N/A|03/03/21|Erling Andersen |MIT|N/A|
|[setuptools](https://pypi.org/project/setuptools)|v65.5.1|11/15/22|snyk-bot |MIT|N/A|
|[sortedcontainers](https://pypi.org/project/sortedcontainers)|N/A|01/09/23|Erling Andersen |Apache-2.0|N/A|
|[sphinx-rtd-theme](https://pypi.org/project/sphinx-rtd-theme)|N/A|10/11/23|Erling Andersen |MIT|N/A|
|[xnat](https://pypi.org/project/xnat)|N/A|01/09/23|Erling Andersen |Apache-2.0|N/A|

<br/>
<div align='center'>

Generated via [Stack File](https://github.com/marketplace/stack-file)
